@@ -4,9 +4,8 @@ import com.unciv.Constants
 import com.unciv.UncivGame
 import com.unciv.UncivGame.Version
 import com.unciv.logic.BackwardCompatibility.convertFortify
-import com.unciv.logic.BackwardCompatibility.convertOldGameSpeed
 import com.unciv.logic.BackwardCompatibility.guaranteeUnitPromotions
-import com.unciv.logic.BackwardCompatibility.migrateBarbarianCamps
+import com.unciv.logic.BackwardCompatibility.migrateToTileHistory
 import com.unciv.logic.BackwardCompatibility.removeMissingModReferences
 import com.unciv.logic.GameInfo.Companion.CURRENT_COMPATIBILITY_NUMBER
 import com.unciv.logic.GameInfo.Companion.FIRST_WITHOUT
@@ -65,8 +64,9 @@ data class CompatibilityVersion(
 
 }
 
-data class VictoryData(val winningCiv:String, val victoryType:String, val victoryTurn:Int){
-    constructor(): this("","",0) // for serializer
+data class VictoryData(val winningCiv: String, val victoryType: String, val victoryTurn: Int) {
+    @Suppress("unused")  // used by json serialization
+    constructor(): this("","",0)
 }
 
 class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion {
@@ -103,6 +103,17 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
     // Set to false whenever the results still need te be processed
     var diplomaticVictoryVotesProcessed = false
 
+    /** The turn the replay history started recording.
+     *
+     *  *   `-1` means the game was serialized with an older version without replay
+     *  *   `0`  would be the normal value in any newer game
+     *      (remember gameParameters.startingEra is not implemented through turns starting > 0)
+     *  *   `>0` would be set by compatibility migration, handled in [BackwardCompatibility.migrateToTileHistory]
+     *
+     *  @see [com.unciv.logic.map.tile.TileHistory]
+     */
+    var historyStartTurn = -1
+
     /**
      * Keep track of a custom location this game was saved to _or_ loaded from, using it as the default custom location for any further save/load attempts.
      */
@@ -164,6 +175,7 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
         toReturn.oneMoreTurnMode = oneMoreTurnMode
         toReturn.customSaveLocation = customSaveLocation
         toReturn.victoryData = victoryData
+        toReturn.historyStartTurn = historyStartTurn
 
         return toReturn
     }
@@ -407,7 +419,7 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
     }
 
     /** Generate a notification pointing out resources.
-     *  Used by [addTechnology][TechManager.addTechnology] and [ResourcesOverviewTab][com.unciv.ui.overviewscreen.ResourcesOverviewTab]
+     *  Used by [addTechnology][TechManager.addTechnology] and [ResourcesOverviewTab][com.unciv.ui.screens.overviewscreen.ResourcesOverviewTab]
      * @param maxDistance from next City, 0 removes distance limitation.
      * @param showForeign Disables filter to exclude foreign territory.
      * @return `false` if no resources were found and no notification was added.
@@ -481,7 +493,6 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
             gameParameters.baseRuleset = baseRulesetInMods
             gameParameters.mods = LinkedHashSet(gameParameters.mods.filter { it != baseRulesetInMods })
         }
-        barbarians.migrateBarbarianCamps()
 
         ruleset = RulesetCache.getComplexRuleset(gameParameters)
 
@@ -497,8 +508,6 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
 
         removeMissingModReferences()
 
-        convertOldGameSpeed()
-
         for (baseUnit in ruleset.units.values)
             baseUnit.ruleset = ruleset
 
@@ -535,12 +544,11 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
 
         convertFortify()
 
-        for (civInfo in sequence {
+        for (civInfo in civilizations.asSequence()
             // update city-state resource first since the happiness of major civ depends on it.
             // See issue: https://github.com/yairm210/Unciv/issues/7781
-            yieldAll(civilizations.filter { it.isCityState() })
-            yieldAll(civilizations.filter { !it.isCityState() })
-        }) {
+            .sortedByDescending { it.isCityState() }
+        ) {
             for (unit in civInfo.units.getCivUnits())
                 unit.updateVisibleTiles(false) // this needs to be done after all the units are assigned to their civs and all other transients are set
             if(civInfo.playerType == PlayerType.Human)
@@ -575,10 +583,6 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
 
                 cityInfo.cityStats.update()
             }
-
-            if (civInfo.hasEverOwnedOriginalCapital == null) {
-                civInfo.hasEverOwnedOriginalCapital = civInfo.cities.any { it.isOriginalCapital }
-            }
         }
 
         spaceResources.clear()
@@ -591,6 +595,8 @@ class GameInfo : IsPartOfGameInfoSerialization, HasGameInfoSerializationVersion
         cityDistances.game = this
 
         guaranteeUnitPromotions()
+
+        migrateToTileHistory()
     }
 
     //endregion
