@@ -26,7 +26,7 @@ import com.unciv.models.ruleset.unique.UniqueTriggerActivation
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.stats.Stat
 import com.unciv.models.stats.Stats
-import com.unciv.ui.utils.extensions.toPercent
+import com.unciv.ui.components.extensions.toPercent
 import com.unciv.utils.debug
 import java.util.*
 import kotlin.math.max
@@ -149,14 +149,31 @@ object Battle {
         if (!defender.isDefeated() && defender is MapUnitCombatant && defender.unit.isExploring())
             defender.unit.action = null
 
+        fun triggerVictoryUniques(ourUnit:MapUnitCombatant, enemy:MapUnitCombatant){
+            val stateForConditionals = StateForConditionals(civInfo = ourUnit.getCivInfo(),
+                ourCombatant = ourUnit, theirCombatant=enemy, tile = attackedTile)
+            for (unique in ourUnit.unit.getTriggeredUniques(UniqueType.TriggerUponDefeatingUnit, stateForConditionals))
+                if (unique.conditionals.any { it.type == UniqueType.TriggerUponDefeatingUnit
+                                && enemy.unit.matchesFilter(it.params[0]) })
+                    UniqueTriggerActivation.triggerUnitwideUnique(unique, ourUnit.unit, triggerNotificationText = "due to our [${ourUnit.getName()}] defeating a [${enemy.getName()}]")
+        }
+
+
         // Add culture when defeating a barbarian when Honor policy is adopted, gold from enemy killed when honor is complete
         // or any enemy military unit with Sacrificial captives unique (can be either attacker or defender!)
         if (defender.isDefeated() && defender is MapUnitCombatant && !defender.unit.isCivilian()) {
             tryEarnFromKilling(attacker, defender)
             tryHealAfterKilling(attacker)
+
+            if (attacker is MapUnitCombatant) triggerVictoryUniques(attacker, defender)
+            triggerDefeatUniques(defender, attacker, attackedTile)
+
         } else if (attacker.isDefeated() && attacker is MapUnitCombatant && !attacker.unit.isCivilian()) {
             tryEarnFromKilling(defender, attacker)
             tryHealAfterKilling(defender)
+
+            if (defender is MapUnitCombatant) triggerVictoryUniques(defender, attacker)
+            triggerDefeatUniques(attacker, defender, attackedTile)
         }
 
         if (attacker is MapUnitCombatant) {
@@ -176,6 +193,13 @@ object Battle {
         if (!isAlreadyDefeatedCity) postBattleAddXp(attacker, defender)
     }
 
+    private fun triggerDefeatUniques(ourUnit: MapUnitCombatant, enemy: ICombatant, attackedTile: Tile){
+        val stateForConditionals = StateForConditionals(civInfo = ourUnit.getCivInfo(),
+            ourCombatant = ourUnit, theirCombatant=enemy, tile = attackedTile)
+        for (unique in ourUnit.unit.getTriggeredUniques(UniqueType.TriggerUponDefeat, stateForConditionals))
+            UniqueTriggerActivation.triggerUnitwideUnique(unique, ourUnit.unit, triggerNotificationText = "due to our [${ourUnit.getName()}] being defeated by a [${enemy.getName()}]")
+    }
+
     private fun tryEarnFromKilling(civUnit: ICombatant, defeatedUnit: MapUnitCombatant) {
         val unitStr = max(defeatedUnit.unit.baseUnit.strength, defeatedUnit.unit.baseUnit.rangedStrength)
         val unitCost = defeatedUnit.unit.baseUnit.cost
@@ -343,6 +367,16 @@ object Battle {
         val defenderDamageDealt = attackerHealthBefore - attacker.getHealth()
         val attackerDamageDealt = defenderHealthBefore - defender.getHealth()
 
+        if (attacker is MapUnitCombatant)
+            for (unique in attacker.unit.getTriggeredUniques(UniqueType.TriggerUponLosingHealth))
+                if (unique.conditionals.any { it.params[0].toInt() <= defenderDamageDealt })
+                    UniqueTriggerActivation.triggerUnitwideUnique(unique, attacker.unit, "due to losing [$defenderDamageDealt] HP")
+
+        if (defender is MapUnitCombatant)
+            for (unique in defender.unit.getTriggeredUniques(UniqueType.TriggerUponLosingHealth))
+                if (unique.conditionals.any { it.params[0].toInt() <= attackerDamageDealt })
+                    UniqueTriggerActivation.triggerUnitwideUnique(unique, defender.unit, "due to losing [$attackerDamageDealt] HP")
+
         plunderFromDamage(attacker, defender, attackerDamageDealt)
         return DamageDealt(attackerDamageDealt, defenderDamageDealt)
     }
@@ -534,7 +568,7 @@ object Battle {
             for (airUnit in airUnits.toList()) airUnit.destroy()
         }
 
-        val stateForConditionals = StateForConditionals(civInfo = attackerCiv, unit = attacker.unit, ourCombatant = attacker, attackedTile = city.getCenterTile())
+        val stateForConditionals = StateForConditionals(civInfo = attackerCiv, city=city, unit = attacker.unit, ourCombatant = attacker, attackedTile = city.getCenterTile())
         for (unique in attacker.getMatchingUniques(UniqueType.CaptureCityPlunder, stateForConditionals, true)) {
             attackerCiv.addStat(
                 Stat.valueOf(unique.params[2]),
@@ -561,9 +595,8 @@ object Battle {
         if (attackerCiv.isCurrentPlayer())
             UncivGame.Current.settings.addCompletedTutorialTask("Conquer a city")
 
-        for (unique in attackerCiv.getTriggeredUniques(UniqueType.TriggerUponConqueringCity,
-                StateForConditionals(attackerCiv, city, attacker.unit, attackedTile = city.getCenterTile() )
-        ))
+        for (unique in attackerCiv.getTriggeredUniques(UniqueType.TriggerUponConqueringCity, stateForConditionals)
+                + attacker.unit.getTriggeredUniques(UniqueType.TriggerUponConqueringCity, stateForConditionals))
             UniqueTriggerActivation.triggerCivwideUnique(unique, attackerCiv, city)
     }
 
@@ -592,7 +625,7 @@ object Battle {
         val capturedUnitTile = capturedUnit.getTile()
         val originalOwner = if (capturedUnit.originalOwner != null)
             capturedUnit.civ.gameInfo.getCivilization(capturedUnit.originalOwner!!)
-            else null
+        else null
 
         var wasDestroyedInstead = false
         when {
@@ -620,34 +653,56 @@ object Battle {
                     && originalOwner.isAlive()
                     && !attacker.getCivInfo().isAtWarWith(originalOwner)
                     && attacker.getCivInfo().playerType == PlayerType.Human // Only humans get the choice
-                -> {
+            -> {
                 capturedUnit.capturedBy(attacker.getCivInfo())
-                attacker.getCivInfo().popupAlerts.add(PopupAlert(AlertType.RecapturedCivilian, capturedUnitTile.position.toString()))
+                attacker.getCivInfo().popupAlerts.add(
+                    PopupAlert(
+                        AlertType.RecapturedCivilian,
+                        capturedUnitTile.position.toString()
+                    )
+                )
             }
 
-            // Captured settlers are converted to workers unless captured by barbarians (so they can be returned later).
-            capturedUnit.hasUnique(UniqueType.FoundCity) && !attacker.getCivInfo().isBarbarian() -> {
-                capturedUnit.destroy()
-                // This is so that future checks which check if a unit has been captured are caught give the right answer
-                //  For example, in postBattleMoveToAttackedTile
-                capturedUnit.civ = attacker.getCivInfo()
-                attacker.getCivInfo().units.placeUnitNearTile(capturedUnitTile.position, Constants.worker)
-            }
-            else -> capturedUnit.capturedBy(attacker.getCivInfo())
+            else -> captureOrConvertToWorker(capturedUnit, attacker.getCivInfo())
         }
 
         if (!wasDestroyedInstead)
-            defenderCiv.addNotification("An enemy [" + attacker.getName() + "] has captured our [" + defender.getName() + "]",
-                defender.getTile().position, NotificationCategory.War, attacker.getName(), NotificationIcon.War, defender.getName())
-        else
-            defenderCiv.addNotification("An enemy [" + attacker.getName() + "] has destroyed our [" + defender.getName() + "]",
-                defender.getTile().position, NotificationCategory.War, attacker.getName(), NotificationIcon.War, defender.getName())
+            defenderCiv.addNotification(
+                "An enemy [${attacker.getName()}] has captured our [${defender.getName()}]",
+                defender.getTile().position, NotificationCategory.War, attacker.getName(),
+                NotificationIcon.War, defender.getName()
+            )
+        else {
+            defenderCiv.addNotification(
+                "An enemy [${attacker.getName()}] has destroyed our [${defender.getName()}]",
+                defender.getTile().position, NotificationCategory.War, attacker.getName(),
+                NotificationIcon.War, defender.getName()
+            )
+            triggerDefeatUniques(defender, attacker, capturedUnitTile)
+        }
 
         if (checkDefeat)
             destroyIfDefeated(defenderCiv, attacker.getCivInfo())
         capturedUnit.updateVisibleTiles()
     }
 
+    fun captureOrConvertToWorker(capturedUnit: MapUnit, capturingCiv: Civilization){
+        // Captured settlers are converted to workers unless captured by barbarians (so they can be returned later).
+        if (capturedUnit.hasUnique(UniqueType.FoundCity) && !capturingCiv.isBarbarian()) {
+            capturedUnit.destroy()
+            // This is so that future checks which check if a unit has been captured are caught give the right answer
+            //  For example, in postBattleMoveToAttackedTile
+            capturedUnit.civ = capturingCiv
+
+            val workerTypeUnit = capturingCiv.gameInfo.ruleset.units.values
+                .firstOrNull { it.isCivilian() && it.getMatchingUniques(UniqueType.BuildImprovements).any { it.params[0] == "Land" } }
+
+            if (workerTypeUnit != null)
+                capturingCiv.units.placeUnitNearTile(capturedUnit.currentTile.position, workerTypeUnit.name)
+        }
+        else capturedUnit.capturedBy(capturingCiv)
+    }
+
     fun destroyIfDefeated(attackedCiv: Civilization, attacker: Civilization) {
         if (attackedCiv.isDefeated()) {
             if (attackedCiv.isCityState())
@@ -1063,9 +1118,10 @@ object Battle {
     }
 
     private fun doDestroyImprovementsAbility(attacker: MapUnitCombatant, attackedTile: Tile, defender: ICombatant) {
+        if (attackedTile.improvement == null) return
+
         val conditionalState = StateForConditionals(attacker.getCivInfo(), ourCombatant = attacker, theirCombatant = defender, combatAction = CombatAction.Attack, attackedTile = attackedTile)
-        if (attackedTile.improvement != Constants.barbarianEncampment
-            && attackedTile.getTileImprovement()?.isAncientRuinsEquivalent() != true
+        if (!attackedTile.getTileImprovement()!!.hasUnique(UniqueType.Unpillagable)
             && attacker.hasUnique(UniqueType.DestroysImprovementUponAttack, conditionalState)
         ) {
             attackedTile.changeImprovement(null)
