@@ -69,6 +69,8 @@ class WorldMapHolder(
 
     private lateinit var tileGroupMap: TileGroupMap<WorldTileGroup>
 
+    lateinit var currentTileSetStrings: TileSetStrings
+
     init {
         if (Gdx.app.type == Application.ApplicationType.Desktop) this.setFlingTime(0f)
         continuousScrollingX = tileMap.mapParameters.worldWrap
@@ -109,6 +111,7 @@ class WorldMapHolder(
 
     internal fun addTiles() {
         val tileSetStrings = TileSetStrings()
+        currentTileSetStrings = tileSetStrings
         val tileGroupsNew = tileMap.values.map { WorldTileGroup(it, tileSetStrings) }
         tileGroupMap = TileGroupMap(this, tileGroupsNew, continuousScrollingX)
 
@@ -206,32 +209,42 @@ class WorldMapHolder(
         removeUnitActionOverlay()
         selectedTile = tile
         unitMovementPaths.clear()
-        worldScreen.shouldUpdate = true
+
+        // Concurrency might open up a race condition window - if worldScreen.shouldUpdate is on too
+        // early, concurrent code might possibly call worldScreen.render() and then our request will be
+        // 'consumed' prematurely, and worse, the update might update and show the BattleTable for our
+        // right-click attack, and leave it visible after we have resolved the battle here in code -
+        // including its onClick closures which will be outdated if the user clicks Attack -> crash!
+        var localShouldUpdate = worldScreen.shouldUpdate
+        worldScreen.shouldUpdate = false
+        // Below, there's 4 outcomes, one of which will have done nothing and will restore the old
+        // shouldUpdate - maybe overkill done in a "better safe than sorry" mindset.
 
         if (worldScreen.bottomUnitTable.selectedUnitIsSwapping) {
+            /** ****** Right-click Swap ****** */
             if (unit.movement.canUnitSwapTo(tile)) {
                 swapMoveUnitToTargetTile(unit, tile)
+                localShouldUpdate = true
+            }
+            /** If we are in unit-swapping mode and didn't find a swap partner, we don't want to move or attack */
+        } else {
+            val attackableTile = BattleHelper
+                    .getAttackableEnemies(unit, unit.movement.getDistanceToTiles())
+                    .firstOrNull { it.tileToAttack == tile }
+            if (unit.canAttack() && attackableTile != null) {
+                /** ****** Right-click Attack ****** */
+                val attacker = MapUnitCombatant(unit)
+                if (!Battle.movePreparingAttack(attacker, attackableTile)) return
+                SoundPlayer.play(attacker.getAttackSound())
+                Battle.attackOrNuke(attacker, attackableTile)
+                localShouldUpdate = true
+            } else if (unit.movement.canReach(tile)) {
+                /** ****** Right-click Move ****** */
+                moveUnitToTargetTile(listOf(unit), tile)
+                localShouldUpdate = true
             }
-            // If we are in unit-swapping mode, we don't want to move or attack
-            return
-        }
-
-        val attackableTile = BattleHelper.getAttackableEnemies(unit, unit.movement.getDistanceToTiles())
-            .firstOrNull { it.tileToAttack == tile }
-        if (unit.canAttack() && attackableTile != null) {
-            worldScreen.shouldUpdate = true
-            val attacker = MapUnitCombatant(unit)
-            if (!Battle.movePreparingAttack(attacker, attackableTile)) return
-            SoundPlayer.play(attacker.getAttackSound())
-            Battle.attackOrNuke(attacker, attackableTile)
-            return
-        }
-
-        val canUnitReachTile = unit.movement.canReach(tile)
-        if (canUnitReachTile) {
-            moveUnitToTargetTile(listOf(unit), tile)
-            return
         }
+        worldScreen.shouldUpdate = localShouldUpdate
     }
 
     private fun moveUnitToTargetTile(selectedUnits: List<MapUnit>, targetTile: Tile) {
@@ -777,6 +790,40 @@ class WorldMapHolder(
             super.reloadMaxZoom()
     }
 
+    override fun restrictX(deltaX: Float): Float {
+        val exploredRegion = worldScreen.viewingCiv.exploredRegion
+        var result = scrollX - deltaX
+
+        if (exploredRegion.shouldRecalculateCoords()) exploredRegion.calculateStageCoords(maxX, maxY)
+
+        if (!exploredRegion.shouldRestrictX()) return result
+
+        val leftX = exploredRegion.getLeftX()
+        val rightX = exploredRegion.getRightX()
+
+        if (deltaX < 0 && scrollX <= rightX && result > rightX)
+            result = rightX
+        else if (deltaX > 0 && scrollX >= leftX && result < leftX)
+            result = leftX
+
+        return result
+    }
+
+    override fun restrictY(deltaY: Float): Float {
+        val exploredRegion = worldScreen.viewingCiv.exploredRegion
+        var result = scrollY + deltaY
+
+        if (exploredRegion.shouldRecalculateCoords()) exploredRegion.calculateStageCoords(maxX, maxY)
+
+        val topY = exploredRegion.getTopY()
+        val bottomY = exploredRegion.getBottomY()
+
+        if (result < topY) result = topY
+        else if (result > bottomY) result = bottomY
+
+        return result
+    }
+
 
     // For debugging purposes
     override fun draw(batch: Batch?, parentAlpha: Float) = super.draw(batch, parentAlpha)
