@@ -1,13 +1,13 @@
 package com.unciv.ui.screens.worldscreen.status
 
-import com.badlogic.gdx.Input
 import com.badlogic.gdx.graphics.Color
 import com.unciv.Constants
 import com.unciv.logic.civilization.managers.ReligionState
 import com.unciv.models.ruleset.BeliefType
 import com.unciv.models.translations.tr
 import com.unciv.ui.components.KeyCharAndCode
-import com.unciv.ui.components.KeyShortcut
+import com.unciv.ui.components.KeyShortcutDispatcher.KeyShortcut
+import com.unciv.ui.components.KeyboardBinding
 import com.unciv.ui.components.extensions.disable
 import com.unciv.ui.components.extensions.enable
 import com.unciv.ui.components.extensions.isEnabled
@@ -35,8 +35,8 @@ class NextTurnButton : IconTextButton("", null, 30) {
 //         label.setFontSize(30)
         labelCell.pad(10f)
         onActivation { nextTurnAction.action() }
-        keyShortcuts.add(Input.Keys.SPACE)
-        keyShortcuts.add('n')
+        keyShortcuts.add(KeyboardBinding.NextTurn)
+        keyShortcuts.add(KeyboardBinding.NextTurnAlternate)
         // Let unit actions override this for command "Wait".
         keyShortcuts.add(KeyShortcut(KeyCharAndCode('z'), -100))
     }
